@@ -15,7 +15,7 @@ ssl._create_default_https_context = ssl._create_unverified_context
 from termcolor import cprint
 from inspect import currentframe
 
-__version__ = '0.1.56'
+__version__ = '0.1.57'
 
 __info__ = {
     '2022/01/04: 0.1.18 加入 __info__。',
@@ -50,8 +50,8 @@ __info__ = {
     '2022/10/30: 0.1.53 price_ticks_offsets_dec()',
     '2022/11/24: 0.1.54 修正一個 redis 非常奇怪的問題',
     '2022/11/27: 0.1.55 加入 shioaji_kline, KLine OHLC',
-    '2022/12/22: 0.1.56 加入 get_new_warrant_list() and add_new_issued_warrant_to_bible()'
-
+    '2022/12/22: 0.1.56 加入 get_new_warrant_list() and add_new_issued_warrant_to_bible()',
+    '2023/01/03: 0.1.57 加入 get_taifex_weight_list()',
 }
 
 request_headers = {
@@ -838,9 +838,30 @@ def get_trade_days(date_start: Union[str, datetime.datetime] = '2018-01-01',
     return list_days
 
 
+def get_taifex_weight_list():
+    import pandas as pd
+    from decimal import Decimal
+    df = pd.read_html('https://www.taifex.com.tw/cht/9/futuresQADetail')
+    list_weight = []
+    try:
+        for x in df[0].to_dict('index').values():
+            list_weight.append({'symbol': x['證券名稱'], 'weight': Decimal(x['市值佔 大盤比重'][:-1])/100})
+            list_weight.append({'symbol': x['證券名稱.2'], 'weight': Decimal(x['市值佔 大盤比重.1'][:-1])/100})
+    except Exception as e:
+        pass
+
+    return list_weight
+
+
+
+
+
 if __name__ == '__main__':
     from time import sleep
 
+    if True:
+        print(get_taifex_weight_list())
+
     if True:
         print(price_ticks_offsets_dec(99, 6))
         print(price_ticks_offsets_dec(99, 6, True))
