@@ -84,7 +84,8 @@ class Tredis_subscribe(threading.Thread):
         self.channel = channel
         self.prefix = prefix
         self.redis_msg_sender = redis_msg_sender
-        self.redis_msg_sender.tredis = self
+        # 很奇怪的 bug。如果加了這行，warrant_detector.py 那邊第一個 redis 就會送不出東西
+        # self.redis_msg_sender.tredis = self
         self.r: redis.client.Redis = None
         self.str_thread_exit_magic = 'redis thread exit'
 
@@ -173,27 +174,54 @@ class Tredis:
         self.tredis_publish.join()
 
 
-
 if __name__ == '__main__':
+
     class warrant_channel:
-        all = 'warrant_all'
-        dealer = 'warrant_dealer'
-        large_volume = 'warrant_large_volume'
-        burst = 'warrant_burst'
+        ALL = 'WARRANT_ALL'
+        DEALER = 'WARRANT_DEALER'
+        LARGE_VOLUME = 'WARRANT_LARGE_VOLUME'
+        BURST = 'WARRANT_BURST'
+
+        AMOUNT_STOCK_AND_WARRANT = 'AMOUNT_STOCK_AND_WARRANT'
+        AMOUNT_WARRANT = 'AMOUNT_WARRANT'
+        AMOUNT_STOCK = 'AMOUNT_STOCK'
 
 
-    logger.disable('mypylib.tredis')
-    tredis = Tredis()
+    # logger.disable('mypylib.tredis')
 
-    tredis.subscribe(warrant_channel.all)
-    tredis.subscribe(warrant_channel.dealer)
-    tredis.subscribe(warrant_channel.large_volume)
-    tredis.subscribe(warrant_channel.burst)
+    sender = base_tredis_msg_sender()
 
-    tredis.publish(warrant_channel.all, warrant_channel.all)
-    tredis.publish(warrant_channel.dealer, warrant_channel.dealer)
-    tredis.publish(warrant_channel.large_volume, warrant_channel.large_volume)
-    tredis.publish(warrant_channel.burst, warrant_channel.burst)
+    tredis = Tredis(server='livewithjoyday.com',
+                    port=Tredis.default_port,
+                    db=Tredis.default_db,
+                    password='5k4g4redisau4a83',
+                    channel='warrant_command',
+                    prefix='warrant',
+                    redis_msg_sender=sender
+                    )
+    tredis_shioaji = Tredis(server='localhost',
+                            port=Tredis.default_port,
+                            db=Tredis.default_db,
+                            password='',
+                            channel='shioaji_wrapper',
+                            prefix='shioaji',
+                            redis_msg_sender=sender
+                            )
+
+
+    tredis.subscribe(warrant_channel.ALL)
+    tredis.subscribe(warrant_channel.DEALER)
+    tredis.subscribe(warrant_channel.LARGE_VOLUME)
+    tredis.subscribe(warrant_channel.BURST)
+
+    tredis.publish(warrant_channel.ALL, warrant_channel.ALL)
+    tredis_shioaji.publish(warrant_channel.ALL, warrant_channel.ALL + ' tredis_shioaji')
+    tredis.publish(warrant_channel.DEALER, warrant_channel.DEALER)
+    tredis_shioaji.publish(warrant_channel.DEALER, warrant_channel.DEALER + ' tredis_shioaji')
+    tredis.publish(warrant_channel.LARGE_VOLUME, warrant_channel.LARGE_VOLUME)
+    tredis_shioaji.publish(warrant_channel.LARGE_VOLUME, warrant_channel.LARGE_VOLUME + ' tredis_shioaji')
+    tredis.publish(warrant_channel.BURST, warrant_channel.BURST)
+    tredis_shioaji.publish(warrant_channel.BURST, warrant_channel.BURST + ' tredis_shioaji')
 
     index = 0
     while True:
@@ -205,4 +233,5 @@ if __name__ == '__main__':
         except KeyboardInterrupt:
             break
 
+    tredis_shioaji.stop()
     tredis.stop()
